# ng-pdf-renderer

A modern, zero-configuration Angular PDF viewer component with built-in controls for navigation, zoom, rotation, search, print, and download.

## ✨ Features

- ✅ **Zero Configuration** - Automatically configures PDF.js worker via CDN
- ✅ **Continuous Scrolling** - View all pages in a single scrollable container
- ✅ **Text Selection & Copy** - Select and copy text directly from PDFs
- ✅ **Search with Highlighting** - Find text within PDFs with visual highlights
- ✅ **Smart Navigation** - Page controls with automatic current page tracking
- ✅ **Zoom & Rotation** - Built-in zoom (50%-200%) and rotation controls
- ✅ **Print & Download** - Easy print and download functionality
- ✅ **Auto-Fit Responsive** - Automatically scales to fit container width
- ✅ **High-DPI Support** - Crystal-sharp rendering on retina displays
- ✅ **Modern Angular 19** - Standalone components with signals
- ✅ **Link Support** - Clickable internal and external PDF links
- ✅ **Form Support** - Interactive PDF forms and annotations

## 📦 Installation

```bash
npm install ng-pdf-renderer
```

## 🚀 Quick Start

### Basic Usage (Minimal Setup)
```typescript
import { Component } from '@angular/core';
import { PdfViewerComponent } from 'ng-pdf-renderer';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [PdfViewerComponent],
  template: `
    <ng-pdf-viewer [src]="pdfUrl"></ng-pdf-viewer>
  `
})
export class AppComponent {
  pdfUrl = '/assets/document.pdf';
}
```

### With Controls Enabled
```typescript
import { PdfViewerComponent, PdfOptions } from 'ng-pdf-renderer';

@Component({
  template: `
    <ng-pdf-viewer 
      [src]="pdfUrl" 
      [options]="options"
      (pageChange)="onPageChange($event)"
      (documentLoaded)="onDocumentLoaded($event)">
    </ng-pdf-viewer>
  `
})
export class MyComponent {
  pdfUrl = 'https://example.com/document.pdf';
  
  options: PdfOptions = {
    height: '800px',
    showControls: true,
    showNavigation: true,
    showZoomControls: true,
    showSearchBar: true,
    enableTextSelection: true
  };

  onPageChange(page: number) {
    console.log('Current page:', page);
  }
  
  onDocumentLoaded(doc: any) {
    console.log('PDF loaded with', doc.numPages, 'pages');
  }
}
```

## ⚙️ Configuration Options

### Mandatory Parameters
| Parameter | Type | Required | Description |
|-----------|------|----------|-------------|
| `src` | `string \| Uint8Array` | **Yes** | PDF source URL or binary data |

### Optional Parameters
| Parameter | Type | Default | Description |
|-----------|------|---------|-------------|
| **Display & Layout** |
| `height` | `string` | `'500px'` | Container height |
| `width` | `string` | `'100%'` | Container width |
| `autoFit` | `boolean` | `true` | Auto-scale to fit container width |
| **UI Controls** |
| `showControls` | `boolean` | `false` | Show control bar |
| `showNavigation` | `boolean` | `true` | Page navigation buttons |
| `showZoomControls` | `boolean` | `true` | Zoom in/out controls |
| `showRotationControls` | `boolean` | `true` | Rotation controls |
| `showDownloadButton` | `boolean` | `true` | Download button |
| `showPrintButton` | `boolean` | `true` | Print button |
| `showSearchBar` | `boolean` | `true` | Search functionality |
| `showThumbnails` | `boolean` | `false` | Thumbnails panel |
| `showOutline` | `boolean` | `false` | Document outline/bookmarks |
| **PDF Rendering** |
| `renderTextLayer` | `boolean` | `true` | Text selection layer |
| `renderAnnotationLayer` | `boolean` | `true` | Links and annotations |
| `enableTextSelection` | `boolean` | `true` | Allow text selection |
| **View Settings** |
| `initialZoom` | `number` | `2.0` | Starting zoom level (200%) |
| `initialPage` | `number` | `1` | Starting page number |
| **Advanced** |
| `workerSrc` | `string` | Auto-detected | PDF.js worker path (CDN) |

## 📤 Events

| Event | Type | Description |
|-------|------|-------------|
| `pageChange` | `number` | Emitted when current page changes |
| `documentLoaded` | `any` | Emitted when PDF document loads successfully |
| `documentLoadError` | `any` | Emitted when PDF loading fails |

## 🎯 Usage Examples

### Loading Different PDF Sources

```typescript
// From URL
pdfUrl = 'https://example.com/document.pdf';

// From assets
pdfUrl = '/assets/document.pdf';

// From file upload
onFileSelected(event: any) {
  const file = event.target.files[0];
  const reader = new FileReader();
  reader.onload = (e) => {
    this.pdfData = new Uint8Array(e.target?.result as ArrayBuffer);
  };
  reader.readAsArrayBuffer(file);
}

// Use binary data
<ng-pdf-viewer [src]="pdfData" [options]="options"></ng-pdf-viewer>
```

### Custom Configuration Examples

```typescript
// Minimal viewer (no controls)
options: PdfOptions = {
  height: '600px'
  // showControls defaults to false
};

// Full-featured viewer
options: PdfOptions = {
  height: '800px',
  showControls: true,
  showThumbnails: true,
  showOutline: true,
  initialZoom: 1.5,
  enableTextSelection: true
};

// Print-friendly (no controls, fit to page)
options: PdfOptions = {
  height: '100vh',
  autoFit: true,
  initialZoom: 1.0,
  showControls: false
};
```

## 🔧 Requirements

- **Angular**: 19.1.0+
- **Browsers**: Modern browsers with ES2022 support
- **TypeScript**: 5.7+

## 🎨 Browser Support

| Browser | Version | Status |
|---------|---------|--------|
| Chrome | Latest | ✅ Fully supported |
| Firefox | Latest | ✅ Fully supported |
| Safari | Latest | ✅ Fully supported |
| Edge | Latest | ✅ Fully supported |

## 🚫 Known Limitations

- Large PDFs (>50MB) may impact performance
- Text selection requires `enableTextSelection: true`
- Thumbnails and outline features are basic implementations
- Form filling is read-only

## 📝 License

MIT License - see [LICENSE](https://github.com/askinjohn/ng-pdf-renderer/blob/main/LICENSE) file

## 🤝 Contributing

Contributions are welcome! Please feel free to:
- Submit bug reports
- Request features
- Submit pull requests

Visit our [GitHub repository](https://github.com/askinjohn/ng-pdf-renderer) for more information.

## 🆘 Support

If you encounter issues:
1. Check the [GitHub Issues](https://github.com/askinjohn/ng-pdf-renderer/issues)
2. Ensure your Angular version is 19.1.0+
3. Verify PDF source is accessible
4. Check browser console for errors
