import * as i0 from '@angular/core';
import { Injectable, inject, EventEmitter, Output, Input, Component, signal, ViewChild } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BehaviorSubject, Subject, takeUntil } from 'rxjs';
import * as pdfjsLib from 'pdfjs-dist';
import * as i2 from '@angular/forms';
import { FormsModule } from '@angular/forms';

/**
 * Service for global configuration of NgPdfRenderer
 * Allows application-wide settings to be applied
 */
class NgPdfRendererConfigService {
    constructor() {
        this._config = {};
    }
    /**
     * Get the current configuration
     */
    get config() {
        return this._config;
    }
    /**
     * Set the configuration for NgPdfRenderer
     * @param config Configuration options
     */
    setConfig(config) {
        this._config = { ...this._config, ...config };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: NgPdfRendererConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: NgPdfRendererConfigService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: NgPdfRendererConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

/**
 * Service handling PDF operations using PDF.js
 * Provides methods to load, navigate, and manipulate PDF documents
 */
class PdfService {
    constructor() {
        // BehaviorSubjects to track PDF state (these emit current value on subscription)
        this.pdfDocumentSubject = new BehaviorSubject(null); // Holds the PDF document object
        this.pdfDocument$ = this.pdfDocumentSubject.asObservable(); // Observable for components to subscribe to
        this.currentPageSubject = new BehaviorSubject(1); // Current page being viewed
        this.currentPage$ = this.currentPageSubject.asObservable();
        this.totalPagesSubject = new BehaviorSubject(0); // Total number of pages in the document
        this.totalPages$ = this.totalPagesSubject.asObservable();
        this.zoomSubject = new BehaviorSubject(1); // Current zoom level (1 = 100%)
        this.zoom$ = this.zoomSubject.asObservable();
        this.rotationSubject = new BehaviorSubject(0); // Current rotation in degrees
        this.rotation$ = this.rotationSubject.asObservable();
        // Properties needed for link service
        this._pdfDocument = null;
        this._viewer = null;
        // Inject the configuration service
        this.configService = inject(NgPdfRendererConfigService);
        // Automatically configure the worker source
        this.configureWorkerSource();
        // Initialize link service
        this.linkService = {
            setDocument: (pdfDocument) => {
                this._pdfDocument = pdfDocument;
            },
            setViewer: (viewer) => {
                this._viewer = viewer;
            },
            navigateTo: (dest) => {
                //console.log('Navigate to:', dest);
                if (dest && typeof dest === 'object' && dest.length > 0) {
                    if (dest[0] && typeof dest[0] === 'object' && 'num' in dest[0]) {
                        // Navigate to page
                        const pageNumber = dest[0].num + 1;
                        this.setCurrentPage(pageNumber);
                        if (this._viewer && this._viewer.scrollPageIntoView) {
                            this._viewer.scrollPageIntoView({ pageNumber });
                        }
                    }
                }
            },
            getDestinationHash: (dest) => {
                return `page=${dest}`;
            },
            getAnchorUrl: (hash) => {
                return `#${hash}`;
            }
        };
    }
    /**
     * Gets the link service for handling annotations
     * @returns The link service instance
     */
    getLinkService() {
        return this.linkService;
    }
    /**
     * Get the current PDF document
     * @returns The current PDF document or null if none is loaded
     */
    getCurrentDocument() {
        return this.pdfDocumentSubject.value;
    }
    /**
     * Configures the PDF.js worker source automatically
     * This eliminates the need for users to manually copy worker files
     */
    configureWorkerSource() {
        // First, check if workerSrc is already set
        if (pdfjsLib.GlobalWorkerOptions.workerSrc) {
            //console.log('Worker already set:', pdfjsLib.GlobalWorkerOptions.workerSrc);
            return;
        }
        // If workerSrc is provided in the config, use it
        if (this.configService.config.workerSrc) {
            //console.log(`Setting worker from config: ${this.configService.config.workerSrc}`);
            pdfjsLib.GlobalWorkerOptions.workerSrc = this.configService.config.workerSrc;
            return;
        }
        // Get the current PDF.js version
        const pdfVersion = pdfjsLib.version;
        // Detect major version to determine worker file name
        const majorVersion = parseInt(pdfVersion.split('.')[0]);
        // PDF.js v4+ uses .mjs files, v3 and below use .min.js
        const workerFile = majorVersion >= 4 ? 'pdf.worker.mjs' : 'pdf.worker.min.js';
        // CDN path to the worker file (using unpkg CDN)
        const cdnWorkerSrc = `https://unpkg.com/pdfjs-dist@${pdfVersion}/build/${workerFile}`;
        //console.log(`PDF.js version ${pdfVersion} detected (v${majorVersion})`);    
        //console.log(`Using PDF.js worker from CDN: ${cdnWorkerSrc}`);
        pdfjsLib.GlobalWorkerOptions.workerSrc = cdnWorkerSrc;
    }
    /**
     * Loads a PDF document from a URL or binary data
     * @param src URL or binary data of the PDF
     * @returns Promise resolving to the loaded PDF document
     */
    async loadDocument(src) {
        try {
            //console.log('PDF.js worker source:', pdfjsLib.GlobalWorkerOptions.workerSrc || 'NOT SET');
            //console.log(`Loading document from: ${typeof src === 'string' ? src : 'Binary data'}`);
            // Create a PDF loading task
            const loadingTask = pdfjsLib.getDocument(src);
            // Add progress tracking
            loadingTask.onProgress = (progressData) => {
                const progress = (progressData.loaded / progressData.total) * 100;
                //console.log(`Loading PDF: ${progress.toFixed(2)}%`);
            };
            // Wait for the document to load
            //console.log('Waiting for PDF document to load...');
            const pdfDocument = await loadingTask.promise;
            //console.log(`PDF document loaded with ${pdfDocument.numPages} pages`);
            // Update subjects with the loaded document info
            this.pdfDocumentSubject.next(pdfDocument);
            this.totalPagesSubject.next(pdfDocument.numPages);
            this.currentPageSubject.next(1); // Reset to first page
            // Configure link service with the document
            this.linkService.setDocument(pdfDocument);
            this.linkService.setViewer({
                scrollPageIntoView: ({ pageNumber }) => {
                    this.setCurrentPage(pageNumber);
                }
            });
            return pdfDocument;
        }
        catch (error) {
            //console.error('Error loading PDF document:', error);
            throw error; // Re-throw to allow component to handle it
        }
    }
    /**
     * Sets the current page to display
     * @param pageNumber The page number to display (1-based index)
     */
    setCurrentPage(pageNumber) {
        const totalPages = this.totalPagesSubject.value;
        // Ensure page number is within valid range
        if (pageNumber >= 1 && pageNumber <= totalPages) {
            this.currentPageSubject.next(pageNumber);
        }
    }
    /**
     * Navigate to the next page if available
     */
    nextPage() {
        const currentPage = this.currentPageSubject.value;
        const totalPages = this.totalPagesSubject.value;
        if (currentPage < totalPages) {
            this.currentPageSubject.next(currentPage + 1);
        }
    }
    /**
     * Navigate to the previous page if available
     */
    previousPage() {
        const currentPage = this.currentPageSubject.value;
        if (currentPage > 1) {
            this.currentPageSubject.next(currentPage - 1);
        }
    }
    /**
     * Set the zoom level for the PDF
     * @param zoom The zoom level (1 = 100%)
     */
    setZoom(zoom) {
        this.zoomSubject.next(zoom);
    }
    /**
     * Increase zoom by 20%
     */
    zoomIn() {
        const currentZoom = this.zoomSubject.value;
        this.zoomSubject.next(currentZoom * 1.2);
    }
    /**
     * Decrease zoom by 20%
     */
    zoomOut() {
        const currentZoom = this.zoomSubject.value;
        this.zoomSubject.next(currentZoom / 1.2);
    }
    /**
     * Rotate the PDF by a specified number of degrees
     * @param degrees The degrees to rotate (positive = clockwise, negative = counterclockwise)
     */
    rotate(degrees) {
        const currentRotation = this.rotationSubject.value;
        // Calculate new rotation and keep it within 0-359 degrees
        let newRotation = (currentRotation + degrees) % 360;
        if (newRotation < 0) {
            newRotation += 360;
        }
        this.rotationSubject.next(newRotation);
    }
    /**
     * Get the document outline (bookmarks)
     * @returns Promise resolving to the outline structure or empty array
     */
    getOutline() {
        const pdfDocument = this.pdfDocumentSubject.value;
        if (!pdfDocument) {
            return Promise.resolve([]);
        }
        // Get outline or return empty array if not available
        return pdfDocument.getOutline() || Promise.resolve([]);
    }
    /**
     * Generate a thumbnail for a specific page
     * @param pageNumber The page number to generate thumbnail for
     * @param scale The scale for the thumbnail (smaller = faster)
     * @returns Promise resolving to data URL of the thumbnail
     */
    async generateThumbnail(pageNumber, scale = 0.2) {
        const pdfDocument = this.pdfDocumentSubject.value;
        if (!pdfDocument) {
            return '';
        }
        try {
            // Get the page object from PDF document
            const page = await pdfDocument.getPage(pageNumber);
            // Create a viewport with the specified scale (smaller for thumbnails)
            const viewport = page.getViewport({ scale });
            // Create an off-screen canvas for rendering
            const canvas = document.createElement('canvas');
            const context = canvas.getContext('2d');
            canvas.height = viewport.height;
            canvas.width = viewport.width;
            // Render the page to the canvas
            await page.render({
                canvasContext: context,
                viewport
            }).promise;
            // Convert canvas to data URL
            return canvas.toDataURL();
        }
        catch (error) {
            //console.error('Error generating thumbnail:', error);
            return '';
        }
    }
    /**
     * Search for text in the PDF document
     * @param text The text to search for
     * @returns Promise resolving to an array of search results
     */
    async search(text) {
        const pdfDocument = this.pdfDocumentSubject.value;
        if (!pdfDocument) {
            //console.warn('No PDF document loaded');
            return [];
        }
        const results = [];
        const totalPages = pdfDocument.numPages;
        // Search through each page
        for (let pageNum = 1; pageNum <= totalPages; pageNum++) {
            try {
                const page = await pdfDocument.getPage(pageNum);
                const textContent = await page.getTextContent();
                const textItems = textContent.items;
                // Search through text items on the page
                for (let i = 0; i < textItems.length; i++) {
                    const item = textItems[i];
                    if (item.str.toLowerCase().includes(text.toLowerCase())) {
                        results.push({
                            pageNumber: pageNum,
                            text: item.str,
                            transform: item.transform,
                            width: item.width,
                            height: item.height
                        });
                    }
                }
            }
            catch (error) {
                //console.error(`Error searching page ${pageNum}:`, error);
            }
        }
        return results;
    }
    /**
     * Download the PDF document
     */
    async downloadPdf() {
        const pdfDocument = this.pdfDocumentSubject.value;
        if (!pdfDocument) {
            return;
        }
        try {
            // Get the binary data of the PDF
            const url = pdfDocument.getData ? await pdfDocument.getData() : null;
            if (url) {
                // Create a blob from binary data
                const blob = new Blob([url], { type: 'application/pdf' });
                const blobUrl = URL.createObjectURL(blob);
                // Create a temporary link element to trigger download
                const link = document.createElement('a');
                link.href = blobUrl;
                // Try to get filename from PDF metadata or use default
                let filename = 'document.pdf';
                try {
                    const metadata = await pdfDocument.getMetadata();
                    if (metadata.info && metadata.info.Title) {
                        filename = `${metadata.info.Title}.pdf`;
                    }
                }
                catch (error) {
                    //console.error('Error getting PDF metadata:', error);
                }
                // Set download attribute and click the link
                link.download = filename;
                link.style.display = 'none';
                document.body.appendChild(link);
                link.click();
                // Clean up DOM and revoke blob URL
                document.body.removeChild(link);
                URL.revokeObjectURL(blobUrl);
            }
            else {
                //console.error('Unable to download: PDF data not available');
            }
        }
        catch (error) {
            //console.error('Error downloading PDF:', error);
        }
    }
    /**
     * Print the PDF document
     */
    async printPdf() {
        const pdfDocument = this.pdfDocumentSubject.value;
        if (!pdfDocument) {
            return;
        }
        try {
            // Create hidden iframe to load PDF for printing
            const printIframe = document.createElement('iframe');
            printIframe.style.position = 'absolute';
            printIframe.style.top = '-1000px';
            printIframe.style.left = '-1000px';
            printIframe.style.width = '0';
            printIframe.style.height = '0';
            document.body.appendChild(printIframe);
            // Get PDF data and create a blob URL
            const data = await pdfDocument.getData();
            const blob = new Blob([data], { type: 'application/pdf' });
            const blobUrl = URL.createObjectURL(blob);
            // Load PDF into iframe
            printIframe.src = blobUrl;
            // Once iframe is loaded, trigger print dialog
            printIframe.onload = () => {
                try {
                    if (printIframe.contentWindow) {
                        // Focus and print the iframe content
                        printIframe.contentWindow.focus();
                        printIframe.contentWindow.print();
                    }
                }
                catch (error) {
                    //console.error('Error printing PDF:', error);
                    // Fallback: open in new tab for user to print
                    window.open(blobUrl, '_blank');
                }
                finally {
                    // Clean up resources (after delay to allow for printing)
                    setTimeout(() => {
                        document.body.removeChild(printIframe);
                        URL.revokeObjectURL(blobUrl);
                    }, 1000);
                }
            };
        }
        catch (error) {
            //console.error('Error setting up PDF print:', error);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

/**
 * Component for PDF controls (navigation, zoom, etc.)
 */
class PdfControlsComponent {
    constructor() {
        // Input properties for control configuration
        this.currentPage = 1; // Current page being displayed
        this.totalPages = 0; // Total pages in document
        this.zoom = 1; // Current zoom level
        this.rotation = 0; // Current rotation in degrees
        // Control visibility options
        this.showNavigation = true; // Show page navigation
        this.showZoomControls = true; // Show zoom controls
        this.showRotationControls = true; // Show rotation controls
        this.showDownloadButton = true; // Show download button
        this.showPrintButton = true; // Show print button
        this.showSearchBar = true; // Show search functionality
        this.showThumbnails = false; // Show thumbnails panel
        this.showOutline = false; // Show outline/bookmarks panel
        // Output events
        this.pageChange = new EventEmitter(); // Page changed
        this.zoomChange = new EventEmitter(); // Zoom changed
        this.rotationChange = new EventEmitter(); // Rotation changed
        this.download = new EventEmitter(); // Download requested
        this.print = new EventEmitter(); // Print requested
        this.search = new EventEmitter(); // Search requested
        this.toggleThumbnails = new EventEmitter(); // Toggle thumbnails
        this.toggleOutline = new EventEmitter(); // Toggle outline
    }
    /**
     * Navigate to first page
     */
    onFirstPage() {
        this.pageChange.emit(1);
    }
    /**
     * Navigate to previous page
     */
    onPreviousPage() {
        if (this.currentPage > 1) {
            this.pageChange.emit(this.currentPage - 1);
        }
    }
    /**
     * Navigate to next page
     */
    onNextPage() {
        if (this.currentPage < this.totalPages) {
            this.pageChange.emit(this.currentPage + 1);
        }
    }
    /**
     * Navigate to last page
     */
    onLastPage() {
        this.pageChange.emit(this.totalPages);
    }
    /**
     * Handle direct page number input
     * @param page The new page number
     */
    onPageInputChange(page) {
        if (page >= 1 && page <= this.totalPages) {
            this.pageChange.emit(page);
        }
    }
    /**
     * Increase zoom by 20%
     */
    onZoomIn() {
        this.zoomChange.emit(this.zoom * 1.2);
    }
    /**
     * Decrease zoom by 20%
     */
    onZoomOut() {
        this.zoomChange.emit(this.zoom / 1.2);
    }
    /**
     * Handle zoom dropdown selection
     * @param zoom The selected zoom level
     */
    onZoomSelect(zoom) {
        this.zoomChange.emit(parseFloat(zoom.toString()));
    }
    /**
     * Rotate counterclockwise by 90 degrees
     */
    onRotateLeft() {
        this.rotationChange.emit(-90);
    }
    /**
     * Rotate clockwise by 90 degrees
     */
    onRotateRight() {
        this.rotationChange.emit(90);
    }
    /**
     * Trigger document download
     */
    onDownload() {
        this.download.emit();
    }
    /**
     * Trigger document printing
     */
    onPrint() {
        this.print.emit();
    }
    /**
     * Execute search if text is provided
     * @param text The text to search for
     */
    onSearch(text) {
        if (text.trim()) {
            this.search.emit(text);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfControlsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.8", type: PdfControlsComponent, isStandalone: true, selector: "ng-pdf-controls", inputs: { currentPage: "currentPage", totalPages: "totalPages", zoom: "zoom", rotation: "rotation", showNavigation: "showNavigation", showZoomControls: "showZoomControls", showRotationControls: "showRotationControls", showDownloadButton: "showDownloadButton", showPrintButton: "showPrintButton", showSearchBar: "showSearchBar", showThumbnails: "showThumbnails", showOutline: "showOutline" }, outputs: { pageChange: "pageChange", zoomChange: "zoomChange", rotationChange: "rotationChange", download: "download", print: "print", search: "search", toggleThumbnails: "toggleThumbnails", toggleOutline: "toggleOutline" }, ngImport: i0, template: `
    <div class="pdf-controls">
      <!-- Page navigation controls -->
      <div class="pdf-navigation" *ngIf="showNavigation">
        <button (click)="onFirstPage()" [disabled]="currentPage <= 1">First</button>
        <button (click)="onPreviousPage()" [disabled]="currentPage <= 1">Previous</button>
        <span class="page-info">
          <!-- Page input with two-way binding -->
          <input type="number" [ngModel]="currentPage" (ngModelChange)="onPageInputChange($event)" min="1" [max]="totalPages">
          / {{ totalPages }}
        </span>
        <button (click)="onNextPage()" [disabled]="currentPage >= totalPages">Next</button>
        <button (click)="onLastPage()" [disabled]="currentPage >= totalPages">Last</button>
      </div>
      
      <!-- Zoom controls -->
      <div class="pdf-zoom" *ngIf="showZoomControls">
        <button (click)="onZoomOut()">-</button>
        <span>{{ (zoom * 100).toFixed(0) }}%</span>
        <button (click)="onZoomIn()">+</button>
        <select [ngModel]="zoom" (ngModelChange)="onZoomSelect($event)">
          <option [value]="0.5">50%</option>
          <option [value]="0.75">75%</option>
          <option [value]="1">100%</option>
          <option [value]="1.25">125%</option>
          <option [value]="1.5">150%</option>
          <option [value]="2">200%</option>
        </select>
      </div>
      
      <!-- Rotation controls -->
      <div class="pdf-rotation" *ngIf="showRotationControls">
        <button (click)="onRotateLeft()">↺</button>
        <button (click)="onRotateRight()">↻</button>
      </div>
      
      <!-- Action buttons -->
      <div class="pdf-actions">
        <button *ngIf="showDownloadButton" (click)="onDownload()">Download</button>
        <button *ngIf="showPrintButton" (click)="onPrint()">Print</button>
      </div>
      
      <!-- Search functionality -->
      <div class="pdf-search" *ngIf="showSearchBar">
        <input type="text" placeholder="Search..." #searchInput>
        <button (click)="onSearch(searchInput.value)">Search</button>
      </div>
    </div>
  `, isInline: true, styles: [".pdf-controls{display:flex;padding:8px;border-bottom:1px solid #ddd;flex-wrap:wrap;gap:10px}.pdf-navigation,.pdf-zoom,.pdf-rotation,.pdf-actions,.pdf-search{display:flex;align-items:center;gap:5px}button{padding:4px 8px;background:#f0f0f0;border:1px solid #ccc;border-radius:3px;cursor:pointer}button:hover{background:#e0e0e0}button:disabled{opacity:.5;cursor:not-allowed}input[type=number],input[type=text]{width:50px;padding:4px;border:1px solid #ccc;border-radius:3px}input[type=text]{width:150px}select{padding:4px;border:1px solid #ccc;border-radius:3px}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.MinValidator, selector: "input[type=number][min][formControlName],input[type=number][min][formControl],input[type=number][min][ngModel]", inputs: ["min"] }, { kind: "directive", type: i2.MaxValidator, selector: "input[type=number][max][formControlName],input[type=number][max][formControl],input[type=number][max][ngModel]", inputs: ["max"] }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfControlsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-pdf-controls', standalone: true, imports: [CommonModule, FormsModule], template: `
    <div class="pdf-controls">
      <!-- Page navigation controls -->
      <div class="pdf-navigation" *ngIf="showNavigation">
        <button (click)="onFirstPage()" [disabled]="currentPage <= 1">First</button>
        <button (click)="onPreviousPage()" [disabled]="currentPage <= 1">Previous</button>
        <span class="page-info">
          <!-- Page input with two-way binding -->
          <input type="number" [ngModel]="currentPage" (ngModelChange)="onPageInputChange($event)" min="1" [max]="totalPages">
          / {{ totalPages }}
        </span>
        <button (click)="onNextPage()" [disabled]="currentPage >= totalPages">Next</button>
        <button (click)="onLastPage()" [disabled]="currentPage >= totalPages">Last</button>
      </div>
      
      <!-- Zoom controls -->
      <div class="pdf-zoom" *ngIf="showZoomControls">
        <button (click)="onZoomOut()">-</button>
        <span>{{ (zoom * 100).toFixed(0) }}%</span>
        <button (click)="onZoomIn()">+</button>
        <select [ngModel]="zoom" (ngModelChange)="onZoomSelect($event)">
          <option [value]="0.5">50%</option>
          <option [value]="0.75">75%</option>
          <option [value]="1">100%</option>
          <option [value]="1.25">125%</option>
          <option [value]="1.5">150%</option>
          <option [value]="2">200%</option>
        </select>
      </div>
      
      <!-- Rotation controls -->
      <div class="pdf-rotation" *ngIf="showRotationControls">
        <button (click)="onRotateLeft()">↺</button>
        <button (click)="onRotateRight()">↻</button>
      </div>
      
      <!-- Action buttons -->
      <div class="pdf-actions">
        <button *ngIf="showDownloadButton" (click)="onDownload()">Download</button>
        <button *ngIf="showPrintButton" (click)="onPrint()">Print</button>
      </div>
      
      <!-- Search functionality -->
      <div class="pdf-search" *ngIf="showSearchBar">
        <input type="text" placeholder="Search..." #searchInput>
        <button (click)="onSearch(searchInput.value)">Search</button>
      </div>
    </div>
  `, styles: [".pdf-controls{display:flex;padding:8px;border-bottom:1px solid #ddd;flex-wrap:wrap;gap:10px}.pdf-navigation,.pdf-zoom,.pdf-rotation,.pdf-actions,.pdf-search{display:flex;align-items:center;gap:5px}button{padding:4px 8px;background:#f0f0f0;border:1px solid #ccc;border-radius:3px;cursor:pointer}button:hover{background:#e0e0e0}button:disabled{opacity:.5;cursor:not-allowed}input[type=number],input[type=text]{width:50px;padding:4px;border:1px solid #ccc;border-radius:3px}input[type=text]{width:150px}select{padding:4px;border:1px solid #ccc;border-radius:3px}\n"] }]
        }], propDecorators: { currentPage: [{
                type: Input
            }], totalPages: [{
                type: Input
            }], zoom: [{
                type: Input
            }], rotation: [{
                type: Input
            }], showNavigation: [{
                type: Input
            }], showZoomControls: [{
                type: Input
            }], showRotationControls: [{
                type: Input
            }], showDownloadButton: [{
                type: Input
            }], showPrintButton: [{
                type: Input
            }], showSearchBar: [{
                type: Input
            }], showThumbnails: [{
                type: Input
            }], showOutline: [{
                type: Input
            }], pageChange: [{
                type: Output
            }], zoomChange: [{
                type: Output
            }], rotationChange: [{
                type: Output
            }], download: [{
                type: Output
            }], print: [{
                type: Output
            }], search: [{
                type: Output
            }], toggleThumbnails: [{
                type: Output
            }], toggleOutline: [{
                type: Output
            }] } });

// REMOVED: import 'pdfjs-dist/web/pdf_viewer.css'; - This is handled in the CSS file
/**
 * Main component for rendering PDFs
 * Uses modern Angular patterns including standalone components and signals
 */
class PdfViewerComponent {
    constructor() {
        // Output events
        this.pageChange = new EventEmitter(); // Emitted when page changes
        this.documentLoaded = new EventEmitter(); // Emitted when document loads
        this.documentLoadError = new EventEmitter(); // Emitted on load error
        // Service injection using modern inject function
        this.pdfService = inject(PdfService);
        // Subject for handling unsubscription on component destroy
        this.destroy$ = new Subject();
        // Component state using signals (reactive primitive in modern Angular)
        this.currentPage = signal(1); // Current page number
        this.totalPages = signal(0); // Total pages in document
        this.zoom = signal(1); // Current zoom level
        this.rotation = signal(0); // Current rotation in degrees
        this.loading = signal(false); // Loading state
        this.error = signal(null); // Error message if any
        // Keep track of current render task to cancel if needed
        this.currentRenderTask = null;
    }
    /**
     * Initialize the component
     */
    ngOnInit() {
        // Apply initial options if provided
        if (this.options?.initialZoom) {
            this.zoom.set(this.options.initialZoom);
            this.pdfService.setZoom(this.options.initialZoom);
        }
        else {
            // Default to a higher zoom level (2.0 = 200%) to better fit screens
            // This seems to work better on modern high-DPI displays
            this.zoom.set(2.0);
            this.pdfService.setZoom(2.0);
        }
        if (this.options?.initialPage) {
            this.currentPage.set(this.options.initialPage);
            this.pdfService.setCurrentPage(this.options.initialPage);
        }
        // Subscribe to service observables and update component state
        // The takeUntil operator automatically unsubscribes when destroy$ emits
        this.pdfService.currentPage$.pipe(takeUntil(this.destroy$))
            .subscribe(page => {
            this.currentPage.set(page);
            this.pageChange.emit(page);
        });
        this.pdfService.totalPages$.pipe(takeUntil(this.destroy$))
            .subscribe(totalPages => {
            this.totalPages.set(totalPages);
        });
        this.pdfService.zoom$.pipe(takeUntil(this.destroy$))
            .subscribe(zoom => {
            this.zoom.set(zoom);
            // Re-render all pages when zoom changes
            if (this.pdfService.getCurrentDocument()) {
                this.renderAllPages();
            }
        });
        this.pdfService.rotation$.pipe(takeUntil(this.destroy$))
            .subscribe(rotation => {
            this.rotation.set(rotation);
            // Re-render all pages when rotation changes
            if (this.pdfService.getCurrentDocument()) {
                this.renderAllPages();
            }
        });
        // Load the document
        this.loadDocument();
    }
    /**
     * Clean up subscriptions on component destruction
     */
    ngOnDestroy() {
        // Cancel any pending render tasks
        if (this.currentRenderTask) {
            try {
                this.currentRenderTask.cancel();
            }
            catch (e) {
                //console.log('Error cancelling render task during destroy:', e);
            }
        }
        // Complete the destroy subject to unsubscribe from all observables
        this.destroy$.next();
        this.destroy$.complete();
    }
    /**
     * Load the PDF document
     */
    async loadDocument() {
        if (!this.src) {
            this.error.set('No PDF source provided');
            return;
        }
        this.loading.set(true);
        this.error.set(null);
        //console.log(`Loading PDF from source: ${typeof this.src === 'string' ? this.src : 'Binary data'}`);
        try {
            // Use service to load the document
            const pdfDocument = await this.pdfService.loadDocument(this.src);
            //console.log('PDF document loaded successfully!', pdfDocument);
            this.documentLoaded.emit(pdfDocument);
            // Set total pages
            this.totalPages.set(pdfDocument.numPages);
            //console.log(`Total pages: ${pdfDocument.numPages}`);
            // Set current page to 1 or initialPage
            const initialPage = this.options?.initialPage || 1;
            this.currentPage.set(initialPage);
            this.pdfService.setCurrentPage(initialPage);
            // Render all pages in continuous mode
            await this.renderAllPages();
        }
        catch (err) {
            //console.error('Error loading PDF:', err);
            this.error.set(err.message || 'Failed to load PDF');
            this.documentLoadError.emit(err);
        }
        finally {
            this.loading.set(false);
        }
    }
    /**
     * Render a specific page of the PDF
     * @param pageNumber The page number to render
     */
    async renderPage(pageNumber) {
        // Ensure there's a page number
        if (!pageNumber) {
            pageNumber = 1;
        }
        //console.log(`Attempting to render page ${pageNumber}`);
        // Cancel any ongoing render task
        if (this.currentRenderTask) {
            //console.log('Cancelling previous render task');
            try {
                await this.currentRenderTask.cancel();
            }
            catch (e) {
                //console.log('Error cancelling previous render task:', e);
            }
            this.currentRenderTask = null;
        }
        try {
            // Get the document directly from the service
            const pdfDocument = this.pdfService.getCurrentDocument();
            if (!pdfDocument) {
                //console.error('No PDF document available');
                return;
            }
            //console.log(`PDF document has ${pdfDocument.numPages} pages`);
            // Get the page from the document
            const page = await pdfDocument.getPage(pageNumber);
            //console.log('Page object retrieved:', page !== null);
            // Calculate scale to fit the canvas
            const scale = this.zoom();
            // Set up viewport based on current zoom and rotation
            const viewport = page.getViewport({
                scale: scale,
                rotation: this.rotation()
            });
            // Clear the canvas container
            const container = this.canvasContainer.nativeElement;
            container.innerHTML = '';
            // Create a new canvas element for this render operation
            const canvas = document.createElement('canvas');
            // Apply device pixel ratio for sharper rendering on high-DPI displays
            const pixelRatio = window.devicePixelRatio || 1;
            // Scale canvas by pixel ratio for sharper rendering
            const scaledWidth = Math.floor(viewport.width * pixelRatio);
            const scaledHeight = Math.floor(viewport.height * pixelRatio);
            // Set canvas dimensions with pixel ratio factored in
            canvas.width = scaledWidth;
            canvas.height = scaledHeight;
            // Set display size through CSS (original size)
            canvas.style.width = Math.floor(viewport.width) + 'px';
            canvas.style.height = Math.floor(viewport.height) + 'px';
            container.appendChild(canvas);
            // Get the canvas context
            const context = canvas.getContext('2d');
            if (!context) {
                //console.error('Canvas rendering context not available');
                this.error.set('Canvas rendering context not available');
                return;
            }
            // Scale the context to account for the device pixel ratio
            context.scale(pixelRatio, pixelRatio);
            //console.log(`Rendering with viewport: ${viewport.width}x${viewport.height}, scale: ${scale}, pixel ratio: ${pixelRatio}`);
            // Render the page to the canvas
            const renderContext = {
                canvasContext: context,
                viewport: viewport
            };
            //console.log('Starting page rendering...');
            // Store the render task for potential cancellation
            this.currentRenderTask = page.render(renderContext);
            // Wait for rendering to complete
            await this.currentRenderTask.promise;
            //console.log('Page rendered successfully');
            this.currentRenderTask = null;
        }
        catch (err) {
            // Check if this is a cancellation error, which is expected when navigating quickly
            if (err && err.name === 'RenderingCancelledException') {
                //console.log('Rendering was cancelled');
            }
            else {
                //console.error('Error rendering page:', err);
                this.error.set(err.message || 'Failed to render PDF page');
            }
        }
    }
    /**
     * Render all pages of the PDF in continuous mode
     */
    async renderAllPages() {
        // Get the document directly from the service
        const pdfDocument = this.pdfService.getCurrentDocument();
        if (!pdfDocument) {
            //console.error('No PDF document available');
            return;
        }
        // Auto-scale to fit the container width if needed
        try {
            if (this.options?.autoFit !== false) {
                const container = this.canvasContainer.nativeElement;
                //console.log('Container width:', container.clientWidth);
                const containerWidth = container.clientWidth || 800; // Fallback to 800 if clientWidth is 0
                const firstPage = await pdfDocument.getPage(1);
                const viewport = firstPage.getViewport({ scale: 1.0 });
                const pageWidth = viewport.width;
                //console.log('Page width at scale 1.0:', pageWidth);
                //console.log('Container width:', containerWidth);
                // Calculate scale to fit container width (with some margin)
                const scaleFactor = Math.max((containerWidth - 40) / pageWidth, 1.5);
                //console.log('Calculated scale factor:', scaleFactor);
                // Only update if significantly different from current zoom
                if (Math.abs(scaleFactor - this.zoom()) > 0.05) {
                    //console.log(`Auto-fitting: scaling to ${scaleFactor.toFixed(2)}`);
                    this.zoom.set(scaleFactor);
                    this.pdfService.setZoom(scaleFactor);
                }
            }
        }
        catch (err) {
            //console.error('Error in auto-scaling:', err);
            // Set a safe default zoom level if auto-scaling fails
            this.zoom.set(1.5);
            this.pdfService.setZoom(1.5);
        }
        const totalPages = pdfDocument.numPages;
        //console.log(`Rendering all ${totalPages} pages`);
        // Clear the canvas container
        const container = this.canvasContainer.nativeElement;
        container.innerHTML = '';
        // Calculate scale based on zoom
        const scale = this.zoom();
        // Render each page
        for (let pageNumber = 1; pageNumber <= totalPages; pageNumber++) {
            try {
                // Get the page
                const page = await pdfDocument.getPage(pageNumber);
                // Create viewport with current zoom and rotation
                const viewport = page.getViewport({
                    scale: scale,
                    rotation: this.rotation()
                });
                // Create page container with margin
                const pageContainer = document.createElement('div');
                pageContainer.className = 'pdf-page';
                pageContainer.style.margin = '10px 0';
                pageContainer.style.position = 'relative';
                pageContainer.style.overflow = 'hidden'; // Prevent overflow issues
                pageContainer.style.backgroundColor = '#fff'; // Add white background
                pageContainer.style.width = Math.floor(viewport.width) + 'px';
                pageContainer.style.height = Math.floor(viewport.height) + 'px';
                pageContainer.setAttribute('data-page-number', pageNumber.toString());
                // Create canvas for this page
                const canvas = document.createElement('canvas');
                // Apply device pixel ratio for sharper rendering on high-DPI displays
                const pixelRatio = window.devicePixelRatio || 1;
                // Scale canvas by pixel ratio for sharper rendering
                const scaledWidth = Math.floor(viewport.width * pixelRatio);
                const scaledHeight = Math.floor(viewport.height * pixelRatio);
                // Set canvas dimensions with pixel ratio factored in
                canvas.width = scaledWidth;
                canvas.height = scaledHeight;
                // Set display size through CSS (original size)
                canvas.style.width = Math.floor(viewport.width) + 'px';
                canvas.style.height = Math.floor(viewport.height) + 'px';
                canvas.style.position = 'absolute';
                canvas.style.top = '0';
                canvas.style.left = '0';
                canvas.style.zIndex = '1';
                pageContainer.appendChild(canvas);
                // Add page number indicator
                const pageIndicator = document.createElement('div');
                pageIndicator.className = 'page-number';
                pageIndicator.textContent = `Page ${pageNumber} of ${totalPages}`;
                pageIndicator.style.position = 'absolute';
                pageIndicator.style.bottom = '5px';
                pageIndicator.style.right = '5px';
                pageIndicator.style.padding = '2px 5px';
                pageIndicator.style.background = 'rgba(255, 255, 255, 0.7)';
                pageIndicator.style.borderRadius = '3px';
                pageIndicator.style.fontSize = '12px';
                pageContainer.appendChild(pageIndicator);
                // Add the page container to the main container
                container.appendChild(pageContainer);
                // Get the canvas context
                const context = canvas.getContext('2d');
                if (!context) {
                    //console.error(`Canvas context not available for page ${pageNumber}`);
                    continue;
                }
                // Scale the context to account for the device pixel ratio
                context.scale(pixelRatio, pixelRatio);
                // Render the page to the canvas
                const renderContext = {
                    canvasContext: context,
                    viewport: viewport
                };
                //console.log(`Rendering page ${pageNumber}...`);
                const renderTask = page.render(renderContext);
                await renderTask.promise;
                //console.log(`Page ${pageNumber} rendered successfully`);
                // ENHANCED TEXT LAYER RENDERING - Key Fix!
                if (this.options?.enableTextSelection !== false) {
                    //console.log(`Adding text layer for page ${pageNumber}...`);
                    const textContent = await page.getTextContent();
                    const textLayerDiv = document.createElement('div');
                    textLayerDiv.className = 'textLayer';
                    // CRITICAL: Proper sizing and positioning with maximum override
                    textLayerDiv.style.cssText = `
              width: ${viewport.width}px !important;
              height: ${viewport.height}px !important;
              position: absolute !important;
              left: 0 !important;
              top: 0 !important;
              overflow: hidden !important;
              line-height: 1.0 !important;
              z-index: 10 !important;
              pointer-events: auto !important;
              opacity: 0.25 !important;
              transform-origin: 0 0 !important;
            `;
                    // CRITICAL: Set the scale factor CSS variable for proper text alignment
                    textLayerDiv.style.setProperty('--scale-factor', scale.toString());
                    //console.log(`Text layer scale factor set to: ${scale}`);
                    //console.log(`Text layer z-index set to: 10`);
                    pageContainer.appendChild(textLayerDiv);
                    try {
                        // Enhanced text layer rendering with better error handling
                        const textLayerRender = pdfjsLib.renderTextLayer({
                            textContentSource: textContent,
                            container: textLayerDiv,
                            viewport: viewport,
                            textDivs: [],
                            // Additional options for better rendering
                            textDivProperties: new WeakMap(),
                            isOffscreenCanvasSupported: false
                        });
                        await textLayerRender.promise;
                        //console.log(`Text layer rendered successfully for page ${pageNumber}`);
                        // Verify text layer content
                        const textSpans = textLayerDiv.querySelectorAll('span');
                        //console.log(`Text layer contains ${textSpans.length} text spans`);
                        // Add debugging info to each span and ensure proper z-index
                        textSpans.forEach((span, index) => {
                            const textContent = span.textContent || '';
                            if (textContent.trim()) {
                                span.setAttribute('data-debug', `span-${index}: "${textContent.substring(0, 20)}"`);
                                // FORCE z-index on each span
                                span.style.cssText += `
                    z-index: 10 !important;
                    pointer-events: auto !important;
                    cursor: text !important;
                  `;
                                // Add selection event listeners for debugging
                                span.addEventListener('mousedown', (e) => {
                                    //console.log('Text selection started on:', textContent.substring(0, 20));
                                    //console.log('Span z-index:', window.getComputedStyle(span).zIndex);
                                    //console.log('Span pointer-events:', window.getComputedStyle(span).pointerEvents);
                                });
                                span.addEventListener('selectstart', () => {
                                    //console.log('Select start event on:', textContent.substring(0, 20));
                                });
                                span.addEventListener('click', () => {
                                    //console.log('Text span clicked:', textContent.substring(0, 20));
                                });
                            }
                        });
                        // Debug: Log the computed styles
                        //console.log('Text layer computed z-index:', window.getComputedStyle(textLayerDiv).zIndex);
                        //console.log('Text layer computed pointer-events:', window.getComputedStyle(textLayerDiv).pointerEvents);
                    }
                    catch (textError) {
                        //console.error(`Error rendering text layer for page ${pageNumber}:`, textError);
                    }
                    // Additional debugging: Force z-index after rendering
                    setTimeout(() => {
                        const finalZIndex = window.getComputedStyle(textLayerDiv).zIndex;
                        //console.log(`Final text layer z-index for page ${pageNumber}:`, finalZIndex);
                        if (finalZIndex !== '10') {
                            //console.warn('Z-index override failed, forcing via JavaScript');
                            textLayerDiv.style.zIndex = '10';
                            textLayerDiv.style.setProperty('z-index', '10', 'important');
                        }
                    }, 100);
                }
                // Add annotation layer if enabled (default is true)
                if (this.options?.renderAnnotationLayer !== false) {
                    // Create annotation layer div
                    const annotationLayerDiv = document.createElement('div');
                    annotationLayerDiv.className = 'annotationLayer';
                    annotationLayerDiv.style.position = 'absolute';
                    annotationLayerDiv.style.top = '0';
                    annotationLayerDiv.style.left = '0';
                    annotationLayerDiv.style.width = '100%';
                    annotationLayerDiv.style.height = '100%';
                    annotationLayerDiv.style.zIndex = '3'; // Ensure it's on top
                    annotationLayerDiv.style.pointerEvents = 'auto';
                    pageContainer.appendChild(annotationLayerDiv);
                    // Get annotations from page
                    const annotations = await page.getAnnotations();
                    if (annotations && annotations.length > 0) {
                        // Process annotation items (focusing on links)
                        annotations.forEach((annotation) => {
                            if (annotation.subtype === 'Link') { // Handle link annotations
                                const linkElement = document.createElement('a');
                                // Position the link
                                const rect = pdfjsLib.Util.normalizeRect([
                                    annotation.rect[0],
                                    annotation.rect[1],
                                    annotation.rect[2],
                                    annotation.rect[3]
                                ]);
                                const bounds = pdfjsLib.Util.getAxialAlignedBoundingBox(rect, viewport.transform);
                                linkElement.style.position = 'absolute';
                                linkElement.style.left = `${bounds[0]}px`;
                                linkElement.style.top = `${bounds[1]}px`;
                                linkElement.style.width = `${bounds[2] - bounds[0]}px`;
                                linkElement.style.height = `${bounds[3] - bounds[1]}px`;
                                linkElement.style.border = '1px solid rgba(0, 0, 255, 0.1)';
                                linkElement.style.backgroundColor = 'rgba(0, 0, 255, 0.1)';
                                linkElement.style.borderRadius = '2px';
                                linkElement.style.zIndex = '3';
                                linkElement.style.cursor = 'pointer';
                                // Handle URL links
                                if (annotation.url) {
                                    linkElement.href = annotation.url;
                                    linkElement.target = '_blank';
                                }
                                // Handle internal page links
                                else if (annotation.dest) {
                                    linkElement.href = '#';
                                    linkElement.addEventListener('click', (e) => {
                                        e.preventDefault();
                                        // Navigate to page destination using the service
                                        this.pdfService.getLinkService().navigateTo(annotation.dest);
                                    });
                                }
                                // Add the link to the annotations layer
                                const linkContainer = document.createElement('div');
                                linkContainer.className = 'linkAnnotation';
                                linkContainer.appendChild(linkElement);
                                annotationLayerDiv.appendChild(linkContainer);
                            }
                        });
                    }
                }
                // Add intersection observer to detect when page is visible
                this.observePageVisibility(pageContainer, pageNumber);
            }
            catch (err) {
                //console.error(`Error rendering page ${pageNumber}:`, err);
            }
        }
    }
    /**
     * Observe page visibility to update current page number
     */
    observePageVisibility(pageElement, pageNumber) {
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting && entry.intersectionRatio > 0.5) {
                    // Update current page without triggering re-render
                    if (this.currentPage() !== pageNumber) {
                        this.currentPage.set(pageNumber);
                        this.pageChange.emit(pageNumber);
                    }
                }
            });
        }, { threshold: 0.5 });
        observer.observe(pageElement);
    }
    /**
     * Handle page change event from controls
     * @param pageNumber The new page number
     */
    onPageChange(pageNumber) {
        this.pdfService.setCurrentPage(pageNumber);
        // Scroll to the selected page
        const container = this.canvasContainer.nativeElement;
        const pageElement = container.querySelector(`[data-page-number="${pageNumber}"]`);
        if (pageElement) {
            pageElement.scrollIntoView({ behavior: 'smooth', block: 'start' });
        }
    }
    /**
     * Handle zoom change event from controls
     * @param zoom The new zoom level
     */
    onZoomChange(zoom) {
        this.pdfService.setZoom(zoom);
    }
    /**
     * Handle rotation change event from controls
     * @param rotation The rotation change in degrees
     */
    onRotationChange(rotation) {
        this.pdfService.rotate(rotation);
    }
    /**
     * Handle download button click
     */
    onDownload() {
        this.pdfService.downloadPdf();
    }
    /**
     * Handle print button click
     */
    onPrint() {
        this.pdfService.printPdf();
    }
    /**
     * Handle search request
     * @param text The text to search for
     */
    async onSearch(text) {
        if (!text.trim()) {
            return;
        }
        // Clear previous highlights
        this.clearSearchHighlights();
        // Perform search
        const results = await this.pdfService.search(text);
        if (results.length === 0) {
            //console.log('No search results found');
            return;
        }
        // Navigate to the first result
        const firstResult = results[0];
        this.onPageChange(firstResult.pageNumber);
        // Highlight all results
        results.forEach(result => {
            const pageElement = this.canvasContainer.nativeElement.querySelector(`[data-page-number="${result.pageNumber}"]`);
            if (pageElement) {
                const textLayer = pageElement.querySelector('.textLayer');
                if (textLayer) {
                    // Find the text span that contains the search text
                    const textSpans = textLayer.querySelectorAll('span');
                    textSpans.forEach(span => {
                        if (span.textContent?.toLowerCase().includes(text.toLowerCase())) {
                            span.classList.add('highlight');
                        }
                    });
                }
            }
        });
    }
    /**
     * Clear all search highlights
     */
    clearSearchHighlights() {
        const highlights = this.canvasContainer.nativeElement.querySelectorAll('.textLayer .highlight');
        highlights.forEach(span => span.classList.remove('highlight'));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfViewerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.8", type: PdfViewerComponent, isStandalone: true, selector: "ng-pdf-viewer", inputs: { src: "src", options: "options" }, outputs: { pageChange: "pageChange", documentLoaded: "documentLoaded", documentLoadError: "documentLoadError" }, viewQueries: [{ propertyName: "canvasContainer", first: true, predicate: ["canvasContainer"], descendants: true, static: true }], ngImport: i0, template: `
    <!-- Main container with configurable dimensions -->
    <div class="pdf-container" [style.width]="options?.width || '100%'" [style.height]="options?.height || '500px'">
      <!-- Controls bar - conditionally shown based on options -->
      <ng-pdf-controls 
        *ngIf="options?.showControls === true"
        [currentPage]="currentPage()"
        [totalPages]="totalPages()"
        [zoom]="zoom()"
        [rotation]="rotation()"
        [showNavigation]="options?.showNavigation !== false"
        [showZoomControls]="options?.showZoomControls !== false"
        [showRotationControls]="options?.showRotationControls !== false"
        [showDownloadButton]="options?.showDownloadButton !== false"
        [showPrintButton]="options?.showPrintButton !== false"
        [showSearchBar]="options?.showSearchBar !== false"
        [showThumbnails]="options?.showThumbnails !== false"
        [showOutline]="options?.showOutline !== false"
        (pageChange)="onPageChange($event)"
        (zoomChange)="onZoomChange($event)"
        (rotationChange)="onRotationChange($event)"
        (download)="onDownload()"
        (print)="onPrint()"
        (search)="onSearch($event)">
      </ng-pdf-controls>
      
      <!-- Main PDF viewing area -->
      <div class="pdf-viewer">
        <!-- Loading indicator -->
        <div class="pdf-loading" *ngIf="loading()">Loading...</div>
        <!-- Error message display -->
        <div class="pdf-error" *ngIf="error()">{{ error() }}</div>
        
        <!-- PDF content container with rotation transform -->
        <div class="pdf-content" [style.transform]="'rotate(' + rotation() + 'deg)'">
          <!-- Canvas where PDF will be rendered -->
          <div #canvasContainer></div>
        </div>
      </div>
      
      <!-- Optional thumbnails panel -->
      <div class="pdf-thumbnails" *ngIf="options?.showThumbnails">
        <!-- Thumbnails will be implemented here -->
      </div>
      
      <!-- Optional outline/bookmarks panel -->
      <div class="pdf-outline" *ngIf="options?.showOutline">
        <!-- Outline will be implemented here -->
      </div>
    </div>
  `, isInline: true, styles: [".pdf-container{display:flex;flex-direction:column;border:1px solid #ddd;overflow:hidden;height:100%}.pdf-viewer{flex:1;overflow:auto;position:relative;background-color:#f5f5f5}.pdf-content{display:flex;flex-direction:column;align-items:center;transition:transform .3s ease;width:100%;padding:20px 0}.pdf-loading,.pdf-error{display:flex;align-items:center;justify-content:center;height:100%;width:100%;position:absolute;top:0;left:0;background-color:#fffc}.pdf-error{color:red}::ng-deep .pdf-page{position:relative;margin:10px 0}::ng-deep .pdf-page canvas{position:absolute;top:0;left:0;z-index:1}::ng-deep .annotationLayer{position:absolute;inset:0;overflow:hidden;z-index:3}::ng-deep .annotationLayer section{position:absolute}::ng-deep .annotationLayer .linkAnnotation>a{position:absolute;font-size:1em;top:0;left:0;width:100%;height:100%;background:#0000000d;cursor:pointer;z-index:3}::ng-deep .annotationLayer .buttonWidgetAnnotation.pushButton>a{background-color:#06f;background-clip:padding-box;border:2px solid #000;border-radius:6px;color:#fff;display:inline-block;padding:4px 8px;cursor:pointer;position:relative;text-decoration:none}::ng-deep .pdf-page .textLayer,::ng-deep div.textLayer{position:absolute!important;text-align:initial!important;inset:0!important;overflow:hidden!important;opacity:.25!important;line-height:1!important;-webkit-text-size-adjust:none!important;-moz-text-size-adjust:none!important;-ms-text-size-adjust:none!important;text-size-adjust:none!important;forced-color-adjust:none!important;transform-origin:0 0!important;z-index:10!important;pointer-events:auto!important}::ng-deep .textLayer span,::ng-deep .textLayer br{color:transparent!important;position:absolute!important;white-space:pre!important;cursor:text!important;transform-origin:0% 0%!important;pointer-events:auto!important;z-index:10!important}::ng-deep .textLayer ::selection{background:#0064ff4d!important;color:#0064ff4d!important}::ng-deep .textLayer ::-moz-selection{background:#0064ff4d!important;color:#0064ff4d!important}::ng-deep .textLayer span::selection{background:#0064ff4d!important}::ng-deep .textLayer span::-moz-selection{background:#0064ff4d!important}::ng-deep .textLayer .endOfContent{display:block;position:absolute;inset:100% 0 0;z-index:-1;cursor:default;user-select:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}::ng-deep .textLayer .highlight{margin:-1px;padding:1px;background-color:#b400aa66;border-radius:4px}::ng-deep .textLayer .highlight.selected{background-color:#00640066}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: PdfControlsComponent, selector: "ng-pdf-controls", inputs: ["currentPage", "totalPages", "zoom", "rotation", "showNavigation", "showZoomControls", "showRotationControls", "showDownloadButton", "showPrintButton", "showSearchBar", "showThumbnails", "showOutline"], outputs: ["pageChange", "zoomChange", "rotationChange", "download", "print", "search", "toggleThumbnails", "toggleOutline"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.8", ngImport: i0, type: PdfViewerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ng-pdf-viewer', standalone: true, imports: [CommonModule, PdfControlsComponent], template: `
    <!-- Main container with configurable dimensions -->
    <div class="pdf-container" [style.width]="options?.width || '100%'" [style.height]="options?.height || '500px'">
      <!-- Controls bar - conditionally shown based on options -->
      <ng-pdf-controls 
        *ngIf="options?.showControls === true"
        [currentPage]="currentPage()"
        [totalPages]="totalPages()"
        [zoom]="zoom()"
        [rotation]="rotation()"
        [showNavigation]="options?.showNavigation !== false"
        [showZoomControls]="options?.showZoomControls !== false"
        [showRotationControls]="options?.showRotationControls !== false"
        [showDownloadButton]="options?.showDownloadButton !== false"
        [showPrintButton]="options?.showPrintButton !== false"
        [showSearchBar]="options?.showSearchBar !== false"
        [showThumbnails]="options?.showThumbnails !== false"
        [showOutline]="options?.showOutline !== false"
        (pageChange)="onPageChange($event)"
        (zoomChange)="onZoomChange($event)"
        (rotationChange)="onRotationChange($event)"
        (download)="onDownload()"
        (print)="onPrint()"
        (search)="onSearch($event)">
      </ng-pdf-controls>
      
      <!-- Main PDF viewing area -->
      <div class="pdf-viewer">
        <!-- Loading indicator -->
        <div class="pdf-loading" *ngIf="loading()">Loading...</div>
        <!-- Error message display -->
        <div class="pdf-error" *ngIf="error()">{{ error() }}</div>
        
        <!-- PDF content container with rotation transform -->
        <div class="pdf-content" [style.transform]="'rotate(' + rotation() + 'deg)'">
          <!-- Canvas where PDF will be rendered -->
          <div #canvasContainer></div>
        </div>
      </div>
      
      <!-- Optional thumbnails panel -->
      <div class="pdf-thumbnails" *ngIf="options?.showThumbnails">
        <!-- Thumbnails will be implemented here -->
      </div>
      
      <!-- Optional outline/bookmarks panel -->
      <div class="pdf-outline" *ngIf="options?.showOutline">
        <!-- Outline will be implemented here -->
      </div>
    </div>
  `, styles: [".pdf-container{display:flex;flex-direction:column;border:1px solid #ddd;overflow:hidden;height:100%}.pdf-viewer{flex:1;overflow:auto;position:relative;background-color:#f5f5f5}.pdf-content{display:flex;flex-direction:column;align-items:center;transition:transform .3s ease;width:100%;padding:20px 0}.pdf-loading,.pdf-error{display:flex;align-items:center;justify-content:center;height:100%;width:100%;position:absolute;top:0;left:0;background-color:#fffc}.pdf-error{color:red}::ng-deep .pdf-page{position:relative;margin:10px 0}::ng-deep .pdf-page canvas{position:absolute;top:0;left:0;z-index:1}::ng-deep .annotationLayer{position:absolute;inset:0;overflow:hidden;z-index:3}::ng-deep .annotationLayer section{position:absolute}::ng-deep .annotationLayer .linkAnnotation>a{position:absolute;font-size:1em;top:0;left:0;width:100%;height:100%;background:#0000000d;cursor:pointer;z-index:3}::ng-deep .annotationLayer .buttonWidgetAnnotation.pushButton>a{background-color:#06f;background-clip:padding-box;border:2px solid #000;border-radius:6px;color:#fff;display:inline-block;padding:4px 8px;cursor:pointer;position:relative;text-decoration:none}::ng-deep .pdf-page .textLayer,::ng-deep div.textLayer{position:absolute!important;text-align:initial!important;inset:0!important;overflow:hidden!important;opacity:.25!important;line-height:1!important;-webkit-text-size-adjust:none!important;-moz-text-size-adjust:none!important;-ms-text-size-adjust:none!important;text-size-adjust:none!important;forced-color-adjust:none!important;transform-origin:0 0!important;z-index:10!important;pointer-events:auto!important}::ng-deep .textLayer span,::ng-deep .textLayer br{color:transparent!important;position:absolute!important;white-space:pre!important;cursor:text!important;transform-origin:0% 0%!important;pointer-events:auto!important;z-index:10!important}::ng-deep .textLayer ::selection{background:#0064ff4d!important;color:#0064ff4d!important}::ng-deep .textLayer ::-moz-selection{background:#0064ff4d!important;color:#0064ff4d!important}::ng-deep .textLayer span::selection{background:#0064ff4d!important}::ng-deep .textLayer span::-moz-selection{background:#0064ff4d!important}::ng-deep .textLayer .endOfContent{display:block;position:absolute;inset:100% 0 0;z-index:-1;cursor:default;user-select:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none}::ng-deep .textLayer .highlight{margin:-1px;padding:1px;background-color:#b400aa66;border-radius:4px}::ng-deep .textLayer .highlight.selected{background-color:#00640066}\n"] }]
        }], propDecorators: { src: [{
                type: Input
            }], options: [{
                type: Input
            }], pageChange: [{
                type: Output
            }], documentLoaded: [{
                type: Output
            }], documentLoadError: [{
                type: Output
            }], canvasContainer: [{
                type: ViewChild,
                args: ['canvasContainer', { static: true }]
            }] } });

/**
 * Public API Surface of ng-pdf-renderer
 * This file exports all the public-facing components, services, and models
 */
// Export components

/**
 * Generated bundle index. Do not edit.
 */

export { NgPdfRendererConfigService, PdfControlsComponent, PdfService, PdfViewerComponent };
//# sourceMappingURL=ng-pdf-renderer.mjs.map
